char *txt_settings=
"------ Settings: --------\n"
"   version: tucnak2-2.48\n"
"    prefix: /usr/local\n"
"  sharedir: /usr/local/share/tucnak2\n"
" interface: ifconf\n"
"  compiler: gcc 4.3.2\n"
"     sizes: int=4, long=8, long long=8, void*=8\n"
" endianity: little\n"
"    CFLAGS: -g -O2 -pthread -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/SDL -D_GNU_SOURCE=1 -D_REENTRANT -I/usr/include/libpng12\n"
"   LDFLAGS: -z now\n"
"      LIBS: -lm -lutil -pthread -lgthread-2.0 -lrt -lglib-2.0 -L/usr/lib -lSDL -lpng12 -lsndfile -lasound -lftdi -lhamlib -lm -lfftw3\n"
"      libc: yes \n"
"  libglib2: yes 2.16.6\n"
"    libsdl: yes 1.2.12\n"
"    libpng: yes 1.2.27\n"
"     iconv: libc\n"
"    libgpm: disabled \n"
"libsndfile: yes 1.0.17\n"
"      alsa: yes 1.0.16\n"
"   libftdi: yes 0.13 new\n"
" libhamlib: yes 1.2.7.1\n"
"  libfftw3: yes\n"
"     ppdev: yes\n"
"  pedantic: no\n"
"leak debug: no\n"
"instrument: no\n"
"      opts: -O2\n"
;
